magnifierConfiguration property

TextMagnifierConfiguration? magnifierConfiguration
finalinherited

The configuration for the magnifier of this text field.

By default, builds a CupertinoTextMagnifier on iOS and TextMagnifier on Android, and builds nothing on all other platforms. To suppress the magnifier, consider passing TextMagnifierConfiguration.disabled.

This magnifying glass is useful for scenarios on mobile devices where the user's finger may be covering part of the screen where a granular action is being performed, such as navigating a small cursor with a drag gesture, on an image or text.

{@tool dartpad} This sample demonstrates how to customize the magnifier that this text field uses.

** See code in examples/api/lib/widgets/text_magnifier/text_magnifier.0.dart ** {@end-tool}

Implementation

final TextMagnifierConfiguration? magnifierConfiguration;